Compare extension

Extension adding comparison operators to String for entity ID ordering.

Provides convenient comparison operators for string-based entity IDs, enabling sorting and range operations on entity identifiers.

on

Operators

operator <(String b) bool

Available on String, provided by the Compare extension

Returns true if this string is lexicographically less than b.
operator <=(String b) bool

Available on String, provided by the Compare extension

Returns true if this string is lexicographically less than or equal to b.
operator >(String b) bool

Available on String, provided by the Compare extension

Returns true if this string is lexicographically greater than b.
operator >=(String b) bool

Available on String, provided by the Compare extension

Returns true if this string is lexicographically greater than or equal to b.