EmptyQuery class

Empty query implementation that retrieves no views.

Used as a placeholder when you need a query but don't want to retrieve any specific data from the entity.

Inheritance

Constructors

EmptyQuery()

Properties

entityName String
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
name String
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
views Map<String, EntityView>
no setterinherited

Methods

add(EntityView view) → void
inherited
childHost(String parentLoggerName, ActorViewHost parent, HordaClientSystem system) → ActorQueryHost
inherited
initViews(EntityQueryGroup views) → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
queryBuilder() QueryDefBuilder
inherited
rootHost(String parentLoggerName, HordaClientSystem system) → ActorQueryHost
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited