EntityCounterView<T> class

View for accessing counter values that support increment/decrement operations.

Counter views maintain integer values that can be incremented, decremented, or reset. They provide real-time updates when the counter value changes.

Example:

final likeCount = EntityCounterView('likes');
Inheritance

Constructors

EntityCounterView(String name, {bool subscribe = true, bool nullable = false})

Properties

convert ViewConvertFunc
finalinherited
hashCode int
The hash code for this object.
no setterinherited
name String
finalinherited
nullable bool
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subscribe bool
finalinherited

Methods

childHost(String parentLoggerName, ActorQueryHost parent, HordaClientSystem system) → ActorViewHost
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
queryBuilder() ViewQueryDefBuilder
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited