EntityDateTimeView class

Specialized view for accessing DateTime values from entities.

Automatically handles conversion from millisecond timestamps to DateTime objects with proper UTC/local timezone handling.

Example:

final createdAt = EntityDateTimeView('createdAt', isUtc: true);
Inheritance

Constructors

EntityDateTimeView(String name, {required bool isUtc, bool subscribe = true, bool nullable = false})

Properties

convert ViewConvertFunc
finalinherited
hashCode int
The hash code for this object.
no setterinherited
isUtc bool
final
name String
finalinherited
nullable bool
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subscribe bool
finalinherited

Methods

childHost(String parentLoggerName, ActorQueryHost parent, HordaClientSystem system) → ActorViewHost
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
queryBuilder() ViewQueryDefBuilder
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited