EntityQueryListHandlerBuilder<Q extends EntityQuery> class

Builder for setting up list change handlers on entity queries.

Allows you to register handlers for list operations like item addition, removal, and clearing.

Constructors

EntityQueryListHandlerBuilder(_Builder<Q> _builder, ListSelector<Q> _sel)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onCleared(ChangeHandler<ListPageCleared> handler) → void
onItemAdded(ChangeHandler<ListPageItemAdded> handler) → void
onItemRemoved(ChangeHandler<ListPageItemRemoved> handler) → void
toString() EntityId
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited