QueryListViewItemRemoved class

Change representing an item being removed from a query list view with position.

Includes the position and reference ID of the removed item.

Inheritance
Annotations
  • @JsonSerializable.new()

Constructors

QueryListViewItemRemoved({required double pos, required EntityId refId})
Creates a query list view item removal change.
QueryListViewItemRemoved.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isOverwriting bool
Whether changes of this type overwrite or accumulate.
no setterinherited
pos double
The position in the list.
final
refId EntityId
The reference ID of the removed item.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

format() String
Returns a formatted string representation of the message content.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts the message to a JSON representation for network transmission.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited