SubscribeActorWsMsg class
- Implemented types
-
- Annotations
-
Properties
-
actorId
→ EntityId
-
final
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
messageType
→ String
-
Type identifier for this message used in JSON serialization.
no setteroverride
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson()
→ Map<String, dynamic>
-
Converts the message to JSON for network transmission.
override
-
toString()
→ String
-
A string representation of this object.
override