ValueQueryResultBuilder class

Builder for value query results.

Constructs value query results from view snapshots.

Inheritance

Constructors

ValueQueryResultBuilder(String name, ViewSnapshot snap)
Creates a value query result builder.

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
Name of the view this result represents.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
snap ViewSnapshot
View snapshot containing the current value and change ID.
finalinherited

Methods

build() ViewQueryResult
Builds the specific ViewQueryResult implementation.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited