ValueViewChanged<T> class

Change representing a new value being set in a typed value view.

The type parameter T represents the declared type of the value view, not necessarily the runtime type of newValue.

Inheritance

Constructors

ValueViewChanged(T newValue)
Creates a value change with the new value.
ValueViewChanged.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isOverwriting bool
Whether changes of this type overwrite or accumulate.
no setterinherited
newValue → T
The new value to set in the view.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

format() String
Returns a formatted string representation of the message content.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts the message to a JSON representation for network transmission.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited