ValueViewConvertFunc<T> typedef

ValueViewConvertFunc<T> = T? Function(dynamic val)

Function type for converting raw values to specific types.

Used by EntityValueView to ensure type safety when converting backend data to the expected Dart type.

Implementation

typedef ValueViewConvertFunc<T> = T? Function(dynamic val);