CallCommandResWsMsg class
- Implemented types
- Annotations
-
- @JsonSerializable.new()
Constructors
-
CallCommandResWsMsg(bool isOk, Map<
String, dynamic> reply) -
CallCommandResWsMsg.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isOk → bool
-
final
- messageType → String
-
Type identifier for this message used in JSON serialization.
no setteroverride
-
reply
→ Map<
String, dynamic> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Converts the message to JSON for network transmission.
override
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited