CounterQueryDef class
Query definition for counter views.
Queries integer counters from entity views that track quantities, counts, or other numeric metrics.
- Inheritance
-
- Object
- ViewQueryDef
- CounterQueryDef
Constructors
- CounterQueryDef({bool subscribe = false})
- Creates a counter view query definition.
-
CounterQueryDef.fromJson(Map<
String, dynamic> json) -
factory
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Converts the query definition to JSON for network transmission.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited