DevtoolEventLog class
This class is used to store and provide DevtoolFluirEvents for the devtool.
It communicates with the devtool by posting DevtoolExtensionEvents where the payload is a DevtoolFluirEvent.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addEvent(
DevtoolFluirEvent fluirEvent) → void - Adds a DevtoolFluirEvent to the log and sends it to the devtool. The devtool should store and process this event.
-
loadDevtool(
) → void -
This method is intended to be called via evalOnDart by devtool on initState and via designated "Reload" button
Posts a DevtoolExtensionLoaded event with all currently stored DevtoolFluirEvents to the devtool. The devtool should load/reload after receiving this event. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → List< Map< String, dynamic> > -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
sendToDevtool(
DevtoolFluirEvent event) → void - Intended to be used outside the 'devtool.dart'. Stores and sends a DevtoolFluirEvent to the devtool if running in debug mode, if not - does nothing. Current mode is checked via kDebugMode.