DevtoolFluirEvent class sealed
Any Fluir related event which should be logged and processed by the devtool.
E.g.: host was created, host projected an event, host was stopped, etc.
Constructors
-
DevtoolFluirEvent.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- path → String
-
The destination where this event happened. Path is used by the devtool to build and navigate the host tree.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → String
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited