EntityCounterView<T> class
View for accessing counter values that support increment/decrement operations.
Counter views maintain integer values that can be incremented, decremented, or reset. They provide real-time updates when the counter value changes.
Example:
final likeCount = EntityCounterView('likes');
- Inheritance
-
- Object
- EntityView
- EntityCounterView
Constructors
- EntityCounterView(String name, {bool subscribe = true, bool nullable = false})
Properties
Methods
-
childHost(
String parentLoggerName, ActorQueryHost parent, HordaClientSystem system) → ActorViewHost -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
queryBuilder(
) → ViewQueryDefBuilder -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited