QueryDef class
Definition of a query to retrieve entity view data.
Specifies which views to query from entities, enabling clients to request specific data projections with optional real-time subscriptions.
Constructors
-
QueryDef(String entityName, Map<
String, ViewQueryDef> views) - Creates a query definition with the specified view queries.
-
QueryDef.fromJson(Map<
String, dynamic> json) -
factory
Properties
- entityName → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
views
→ Map<
String, ViewQueryDef> -
Map of view names to their query definitions.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited