ReplyClient class final
Information for routing command replies back to clients.
Contains identifiers needed to deliver events from command processing back to the client application that originated the request.
- Annotations
-
- @JsonSerializable.new(anyMap: true)
Constructors
- ReplyClient({required String serverId, required String sessionId, required String callId})
- Creates reply client information for client communication.
-
ReplyClient.fromJson(Map<
String, dynamic> json) -
factory
- ReplyClient.none()
- Creates empty reply client when no client reply is needed.
Properties
- callId → String
-
Unique identifier for the specific client call.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- serverId → String
-
Identifier of the server instance handling the client connection.
final
- sessionId → String
-
Client session identifier for routing replies.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited