SendCommandWsMsg class
Message for sending commands to entities or services.
Fire-and-forget command delivery without waiting for response.
- Implemented types
Constructors
- SendCommandWsMsg(String actorName, EntityId to, RemoteCommand cmd)
- Creates a send command message.
-
SendCommandWsMsg.fromJson(Map<
String, dynamic> json) -
factory
Properties
- actorName → String
-
Name of the target entity or service type.
final
-
cmd
→ Map<
String, dynamic> -
JSON of the command which is being sent.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- messageType → String
-
Type identifier for this message used in JSON serialization.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- to → String
-
ID of the specific entity instance to send to.
final
- type → String
-
Type of the command which is being sent.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Converts the message to JSON for network transmission.
override
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited