ValueQueryResult class
Query result for value views.
Contains a single typed value retrieved from an entity view.
- Inheritance
-
- Object
- ViewQueryResult
- ValueQueryResult
Constructors
- ValueQueryResult(dynamic value, String changeId)
- Creates a value query result.
-
ValueQueryResult.fromJson(Map<
String, dynamic> json) -
factory
Properties
- changeId → String
-
Change ID indicating the version of this result.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → dynamic
-
The value retrieved from the view.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Converts the result to JSON for network transmission.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited